# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SubscriptionArgs', 'Subscription']

@pulumi.input_type
class SubscriptionArgs:
    def __init__(__self__, *,
                 project_name: pulumi.Input[str],
                 topic_name: pulumi.Input[str],
                 comment: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Subscription resource.
        :param pulumi.Input[str] project_name: The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        :param pulumi.Input[str] topic_name: The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        :param pulumi.Input[str] comment: Comment of the datahub subscription. It cannot be longer than 255 characters.
        """
        pulumi.set(__self__, "project_name", project_name)
        pulumi.set(__self__, "topic_name", topic_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Input[str]:
        """
        The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Input[str]:
        """
        The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "topic_name", value)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Comment of the datahub subscription. It cannot be longer than 255 characters.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)


@pulumi.input_type
class _SubscriptionState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 last_modify_time: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 sub_id: Optional[pulumi.Input[str]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Subscription resources.
        :param pulumi.Input[str] comment: Comment of the datahub subscription. It cannot be longer than 255 characters.
        :param pulumi.Input[str] create_time: Create time of the datahub subscription. It is a human-readable string rather than 64-bits UTC.
        :param pulumi.Input[str] last_modify_time: Last modify time of the datahub subscription. It is the same as *create_time* at the beginning. It is also a human-readable string rather than 64-bits UTC.
        :param pulumi.Input[str] project_name: The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        :param pulumi.Input[str] sub_id: The identidy of the subscription, generate from server side.
        :param pulumi.Input[str] topic_name: The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if last_modify_time is not None:
            pulumi.set(__self__, "last_modify_time", last_modify_time)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if sub_id is not None:
            pulumi.set(__self__, "sub_id", sub_id)
        if topic_name is not None:
            pulumi.set(__self__, "topic_name", topic_name)

    @property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[str]]:
        """
        Comment of the datahub subscription. It cannot be longer than 255 characters.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "comment", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Create time of the datahub subscription. It is a human-readable string rather than 64-bits UTC.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="lastModifyTime")
    def last_modify_time(self) -> Optional[pulumi.Input[str]]:
        """
        Last modify time of the datahub subscription. It is the same as *create_time* at the beginning. It is also a human-readable string rather than 64-bits UTC.
        """
        return pulumi.get(self, "last_modify_time")

    @last_modify_time.setter
    def last_modify_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_modify_time", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="subId")
    def sub_id(self) -> Optional[pulumi.Input[str]]:
        """
        The identidy of the subscription, generate from server side.
        """
        return pulumi.get(self, "sub_id")

    @sub_id.setter
    def sub_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sub_id", value)

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "topic_name")

    @topic_name.setter
    def topic_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "topic_name", value)


class Subscription(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        The subscription is the basic unit of resource usage in Datahub Service under Publish/Subscribe model. You can manage the relationships between user and topics by using subscriptions. [Refer to details](https://help.aliyun.com/document_detail/47440.html).

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.datahub.Subscription("example",
            comment="created by terraform",
            project_name="tf_datahub_project",
            topic_name="tf_datahub_topic")
        ```

        ## Import

        Datahub subscription can be imported using the ID, e.g.

        ```sh
         $ pulumi import alicloud:datahub/subscription:Subscription example tf_datahub_project:tf_datahub_topic:1539073399567UgCzY
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Comment of the datahub subscription. It cannot be longer than 255 characters.
        :param pulumi.Input[str] project_name: The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        :param pulumi.Input[str] topic_name: The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SubscriptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The subscription is the basic unit of resource usage in Datahub Service under Publish/Subscribe model. You can manage the relationships between user and topics by using subscriptions. [Refer to details](https://help.aliyun.com/document_detail/47440.html).

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        example = alicloud.datahub.Subscription("example",
            comment="created by terraform",
            project_name="tf_datahub_project",
            topic_name="tf_datahub_topic")
        ```

        ## Import

        Datahub subscription can be imported using the ID, e.g.

        ```sh
         $ pulumi import alicloud:datahub/subscription:Subscription example tf_datahub_project:tf_datahub_topic:1539073399567UgCzY
        ```

        :param str resource_name: The name of the resource.
        :param SubscriptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SubscriptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[str]] = None,
                 project_name: Optional[pulumi.Input[str]] = None,
                 topic_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SubscriptionArgs.__new__(SubscriptionArgs)

            __props__.__dict__["comment"] = comment
            if project_name is None and not opts.urn:
                raise TypeError("Missing required property 'project_name'")
            __props__.__dict__["project_name"] = project_name
            if topic_name is None and not opts.urn:
                raise TypeError("Missing required property 'topic_name'")
            __props__.__dict__["topic_name"] = topic_name
            __props__.__dict__["create_time"] = None
            __props__.__dict__["last_modify_time"] = None
            __props__.__dict__["sub_id"] = None
        super(Subscription, __self__).__init__(
            'alicloud:datahub/subscription:Subscription',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            last_modify_time: Optional[pulumi.Input[str]] = None,
            project_name: Optional[pulumi.Input[str]] = None,
            sub_id: Optional[pulumi.Input[str]] = None,
            topic_name: Optional[pulumi.Input[str]] = None) -> 'Subscription':
        """
        Get an existing Subscription resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] comment: Comment of the datahub subscription. It cannot be longer than 255 characters.
        :param pulumi.Input[str] create_time: Create time of the datahub subscription. It is a human-readable string rather than 64-bits UTC.
        :param pulumi.Input[str] last_modify_time: Last modify time of the datahub subscription. It is the same as *create_time* at the beginning. It is also a human-readable string rather than 64-bits UTC.
        :param pulumi.Input[str] project_name: The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        :param pulumi.Input[str] sub_id: The identidy of the subscription, generate from server side.
        :param pulumi.Input[str] topic_name: The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SubscriptionState.__new__(_SubscriptionState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["last_modify_time"] = last_modify_time
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["sub_id"] = sub_id
        __props__.__dict__["topic_name"] = topic_name
        return Subscription(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def comment(self) -> pulumi.Output[Optional[str]]:
        """
        Comment of the datahub subscription. It cannot be longer than 255 characters.
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Create time of the datahub subscription. It is a human-readable string rather than 64-bits UTC.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="lastModifyTime")
    def last_modify_time(self) -> pulumi.Output[str]:
        """
        Last modify time of the datahub subscription. It is the same as *create_time* at the beginning. It is also a human-readable string rather than 64-bits UTC.
        """
        return pulumi.get(self, "last_modify_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[str]:
        """
        The name of the datahub project that the subscription belongs to. Its length is limited to 3-32 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="subId")
    def sub_id(self) -> pulumi.Output[str]:
        """
        The identidy of the subscription, generate from server side.
        """
        return pulumi.get(self, "sub_id")

    @property
    @pulumi.getter(name="topicName")
    def topic_name(self) -> pulumi.Output[str]:
        """
        The name of the datahub topic that the subscription belongs to. Its length is limited to 1-128 and only characters such as letters, digits and '_' are allowed. It is case-insensitive.
        """
        return pulumi.get(self, "topic_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetIndustrialPidLoopsResult',
    'AwaitableGetIndustrialPidLoopsResult',
    'get_industrial_pid_loops',
    'get_industrial_pid_loops_output',
]

@pulumi.output_type
class GetIndustrialPidLoopsResult:
    """
    A collection of values returned by getIndustrialPidLoops.
    """
    def __init__(__self__, enable_details=None, id=None, ids=None, loops=None, name_regex=None, names=None, output_file=None, pid_loop_name=None, pid_project_id=None, status=None):
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if loops and not isinstance(loops, list):
            raise TypeError("Expected argument 'loops' to be a list")
        pulumi.set(__self__, "loops", loops)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if pid_loop_name and not isinstance(pid_loop_name, str):
            raise TypeError("Expected argument 'pid_loop_name' to be a str")
        pulumi.set(__self__, "pid_loop_name", pid_loop_name)
        if pid_project_id and not isinstance(pid_project_id, str):
            raise TypeError("Expected argument 'pid_project_id' to be a str")
        pulumi.set(__self__, "pid_project_id", pid_project_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def loops(self) -> Sequence['outputs.GetIndustrialPidLoopsLoopResult']:
        return pulumi.get(self, "loops")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pidLoopName")
    def pid_loop_name(self) -> Optional[str]:
        return pulumi.get(self, "pid_loop_name")

    @property
    @pulumi.getter(name="pidProjectId")
    def pid_project_id(self) -> str:
        return pulumi.get(self, "pid_project_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetIndustrialPidLoopsResult(GetIndustrialPidLoopsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIndustrialPidLoopsResult(
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            loops=self.loops,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            pid_loop_name=self.pid_loop_name,
            pid_project_id=self.pid_project_id,
            status=self.status)


def get_industrial_pid_loops(enable_details: Optional[bool] = None,
                             ids: Optional[Sequence[str]] = None,
                             name_regex: Optional[str] = None,
                             output_file: Optional[str] = None,
                             pid_loop_name: Optional[str] = None,
                             pid_project_id: Optional[str] = None,
                             status: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIndustrialPidLoopsResult:
    """
    This data source provides the Brain Industrial Pid Loops of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.117.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.brain.get_industrial_pid_loops(pid_project_id="856c6b8f-ca63-40a4-xxxx-xxxx",
        ids=["742a3d4e-d8b0-47c8-xxxx-xxxx"],
        name_regex="tf-testACC")
    pulumi.export("firstBrainIndustrialPidLoopId", example.loops[0].id)
    ```


    :param Sequence[str] ids: A list of Pid Loop IDs.
    :param str name_regex: A regex string to filter results by Pid Loop name.
    :param str pid_loop_name: The name of Pid Loop.
    :param str pid_project_id: The pid project id.
    :param str status: The status of Pid Loop.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pidLoopName'] = pid_loop_name
    __args__['pidProjectId'] = pid_project_id
    __args__['status'] = status
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:brain/getIndustrialPidLoops:getIndustrialPidLoops', __args__, opts=opts, typ=GetIndustrialPidLoopsResult).value

    return AwaitableGetIndustrialPidLoopsResult(
        enable_details=__ret__.enable_details,
        id=__ret__.id,
        ids=__ret__.ids,
        loops=__ret__.loops,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        pid_loop_name=__ret__.pid_loop_name,
        pid_project_id=__ret__.pid_project_id,
        status=__ret__.status)


@_utilities.lift_output_func(get_industrial_pid_loops)
def get_industrial_pid_loops_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                    ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                    name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                    output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                    pid_loop_name: Optional[pulumi.Input[Optional[str]]] = None,
                                    pid_project_id: Optional[pulumi.Input[str]] = None,
                                    status: Optional[pulumi.Input[Optional[str]]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIndustrialPidLoopsResult]:
    """
    This data source provides the Brain Industrial Pid Loops of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.117.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.brain.get_industrial_pid_loops(pid_project_id="856c6b8f-ca63-40a4-xxxx-xxxx",
        ids=["742a3d4e-d8b0-47c8-xxxx-xxxx"],
        name_regex="tf-testACC")
    pulumi.export("firstBrainIndustrialPidLoopId", example.loops[0].id)
    ```


    :param Sequence[str] ids: A list of Pid Loop IDs.
    :param str name_regex: A regex string to filter results by Pid Loop name.
    :param str pid_loop_name: The name of Pid Loop.
    :param str pid_project_id: The pid project id.
    :param str status: The status of Pid Loop.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'AccessStrategyDefaultAddrPoolArgs',
    'AccessStrategyFailoverAddrPoolArgs',
    'AccessStrategyLineArgs',
    'AddressPoolAddressArgs',
    'CustomLineIpSegmentListArgs',
    'GtmInstanceAlertConfigArgs',
    'MonitorConfigIspCityNodeArgs',
]

@pulumi.input_type
class AccessStrategyDefaultAddrPoolArgs:
    def __init__(__self__, *,
                 addr_pool_id: pulumi.Input[str],
                 lba_weight: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] addr_pool_id: The ID of the address pool in the primary address pool group.
        :param pulumi.Input[int] lba_weight: The weight of the address pool in the primary address pool group.
        """
        pulumi.set(__self__, "addr_pool_id", addr_pool_id)
        if lba_weight is not None:
            pulumi.set(__self__, "lba_weight", lba_weight)

    @property
    @pulumi.getter(name="addrPoolId")
    def addr_pool_id(self) -> pulumi.Input[str]:
        """
        The ID of the address pool in the primary address pool group.
        """
        return pulumi.get(self, "addr_pool_id")

    @addr_pool_id.setter
    def addr_pool_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "addr_pool_id", value)

    @property
    @pulumi.getter(name="lbaWeight")
    def lba_weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the address pool in the primary address pool group.
        """
        return pulumi.get(self, "lba_weight")

    @lba_weight.setter
    def lba_weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lba_weight", value)


@pulumi.input_type
class AccessStrategyFailoverAddrPoolArgs:
    def __init__(__self__, *,
                 addr_pool_id: Optional[pulumi.Input[str]] = None,
                 lba_weight: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[str] addr_pool_id: The ID of the address pool in the primary address pool group.
        :param pulumi.Input[int] lba_weight: The weight of the address pool in the primary address pool group.
        """
        if addr_pool_id is not None:
            pulumi.set(__self__, "addr_pool_id", addr_pool_id)
        if lba_weight is not None:
            pulumi.set(__self__, "lba_weight", lba_weight)

    @property
    @pulumi.getter(name="addrPoolId")
    def addr_pool_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the address pool in the primary address pool group.
        """
        return pulumi.get(self, "addr_pool_id")

    @addr_pool_id.setter
    def addr_pool_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "addr_pool_id", value)

    @property
    @pulumi.getter(name="lbaWeight")
    def lba_weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the address pool in the primary address pool group.
        """
        return pulumi.get(self, "lba_weight")

    @lba_weight.setter
    def lba_weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lba_weight", value)


@pulumi.input_type
class AccessStrategyLineArgs:
    def __init__(__self__, *,
                 line_code: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] line_code: The line code of the source region.
        """
        if line_code is not None:
            pulumi.set(__self__, "line_code", line_code)

    @property
    @pulumi.getter(name="lineCode")
    def line_code(self) -> Optional[pulumi.Input[str]]:
        """
        The line code of the source region.
        """
        return pulumi.get(self, "line_code")

    @line_code.setter
    def line_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line_code", value)


@pulumi.input_type
class AddressPoolAddressArgs:
    def __init__(__self__, *,
                 address: pulumi.Input[str],
                 attribute_info: pulumi.Input[str],
                 mode: pulumi.Input[str],
                 lba_weight: Optional[pulumi.Input[int]] = None,
                 remark: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] address: The address that you want to add to the address pool.
        :param pulumi.Input[str] attribute_info: The source region of the address. expressed as a JSON string. The structure is as follows:
               * `LineCodes`: List of home lineCodes.
               * `lineCodeRectifyType`: The rectification type of the line code. Default value: `AUTO`. Valid values: `NO_NEED`: no need for rectification. `RECTIFIED`: rectified. `AUTO`: automatic rectification.
        :param pulumi.Input[str] mode: The type of the address. Valid values:`SMART`, `ONLINE` and `OFFLINE`.
        :param pulumi.Input[int] lba_weight: The weight of the address. **NOTE:** The attribute is valid when the attribute `lba_strategy` is `RATIO`.
        :param pulumi.Input[str] remark: The description of the address.
        """
        pulumi.set(__self__, "address", address)
        pulumi.set(__self__, "attribute_info", attribute_info)
        pulumi.set(__self__, "mode", mode)
        if lba_weight is not None:
            pulumi.set(__self__, "lba_weight", lba_weight)
        if remark is not None:
            pulumi.set(__self__, "remark", remark)

    @property
    @pulumi.getter
    def address(self) -> pulumi.Input[str]:
        """
        The address that you want to add to the address pool.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: pulumi.Input[str]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="attributeInfo")
    def attribute_info(self) -> pulumi.Input[str]:
        """
        The source region of the address. expressed as a JSON string. The structure is as follows:
        * `LineCodes`: List of home lineCodes.
        * `lineCodeRectifyType`: The rectification type of the line code. Default value: `AUTO`. Valid values: `NO_NEED`: no need for rectification. `RECTIFIED`: rectified. `AUTO`: automatic rectification.
        """
        return pulumi.get(self, "attribute_info")

    @attribute_info.setter
    def attribute_info(self, value: pulumi.Input[str]):
        pulumi.set(self, "attribute_info", value)

    @property
    @pulumi.getter
    def mode(self) -> pulumi.Input[str]:
        """
        The type of the address. Valid values:`SMART`, `ONLINE` and `OFFLINE`.
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: pulumi.Input[str]):
        pulumi.set(self, "mode", value)

    @property
    @pulumi.getter(name="lbaWeight")
    def lba_weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the address. **NOTE:** The attribute is valid when the attribute `lba_strategy` is `RATIO`.
        """
        return pulumi.get(self, "lba_weight")

    @lba_weight.setter
    def lba_weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "lba_weight", value)

    @property
    @pulumi.getter
    def remark(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the address.
        """
        return pulumi.get(self, "remark")

    @remark.setter
    def remark(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "remark", value)


@pulumi.input_type
class CustomLineIpSegmentListArgs:
    def __init__(__self__, *,
                 end_ip: pulumi.Input[str],
                 start_ip: pulumi.Input[str]):
        """
        :param pulumi.Input[str] end_ip: The end IP address of the CIDR block.
        :param pulumi.Input[str] start_ip: The start IP address of the CIDR block.
        """
        pulumi.set(__self__, "end_ip", end_ip)
        pulumi.set(__self__, "start_ip", start_ip)

    @property
    @pulumi.getter(name="endIp")
    def end_ip(self) -> pulumi.Input[str]:
        """
        The end IP address of the CIDR block.
        """
        return pulumi.get(self, "end_ip")

    @end_ip.setter
    def end_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "end_ip", value)

    @property
    @pulumi.getter(name="startIp")
    def start_ip(self) -> pulumi.Input[str]:
        """
        The start IP address of the CIDR block.
        """
        return pulumi.get(self, "start_ip")

    @start_ip.setter
    def start_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "start_ip", value)


@pulumi.input_type
class GtmInstanceAlertConfigArgs:
    def __init__(__self__, *,
                 dingtalk_notice: Optional[pulumi.Input[bool]] = None,
                 email_notice: Optional[pulumi.Input[bool]] = None,
                 notice_type: Optional[pulumi.Input[str]] = None,
                 sms_notice: Optional[pulumi.Input[bool]] = None):
        """
        :param pulumi.Input[bool] dingtalk_notice: Whether to configure DingTalk notifications. Valid values: `true`, `false`.
        :param pulumi.Input[bool] email_notice: Whether to configure mail notification. Valid values: `true`, `false`.
        :param pulumi.Input[str] notice_type: The Alarm Event Type.
               - `ADDR_ALERT`: Address not available.
               - `ADDR_RESUME`: Address Recovery available.
               - `ADDR_POOL_GROUP_UNAVAILABLE`: Address pool collection not available.
               - `ADDR_POOL_GROUP_AVAILABLE`: Address pool collection recovery available.
               - `ACCESS_STRATEGY_POOL_GROUP_SWITCH`: Primary/standby address pool switch.
               - `MONITOR_NODE_IP_CHANGE`: Monitoring node IP address changes.
        :param pulumi.Input[bool] sms_notice: Whether to configure SMS notification. Valid values: `true`, `false`.
        """
        if dingtalk_notice is not None:
            pulumi.set(__self__, "dingtalk_notice", dingtalk_notice)
        if email_notice is not None:
            pulumi.set(__self__, "email_notice", email_notice)
        if notice_type is not None:
            pulumi.set(__self__, "notice_type", notice_type)
        if sms_notice is not None:
            pulumi.set(__self__, "sms_notice", sms_notice)

    @property
    @pulumi.getter(name="dingtalkNotice")
    def dingtalk_notice(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to configure DingTalk notifications. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "dingtalk_notice")

    @dingtalk_notice.setter
    def dingtalk_notice(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dingtalk_notice", value)

    @property
    @pulumi.getter(name="emailNotice")
    def email_notice(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to configure mail notification. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "email_notice")

    @email_notice.setter
    def email_notice(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "email_notice", value)

    @property
    @pulumi.getter(name="noticeType")
    def notice_type(self) -> Optional[pulumi.Input[str]]:
        """
        The Alarm Event Type.
        - `ADDR_ALERT`: Address not available.
        - `ADDR_RESUME`: Address Recovery available.
        - `ADDR_POOL_GROUP_UNAVAILABLE`: Address pool collection not available.
        - `ADDR_POOL_GROUP_AVAILABLE`: Address pool collection recovery available.
        - `ACCESS_STRATEGY_POOL_GROUP_SWITCH`: Primary/standby address pool switch.
        - `MONITOR_NODE_IP_CHANGE`: Monitoring node IP address changes.
        """
        return pulumi.get(self, "notice_type")

    @notice_type.setter
    def notice_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notice_type", value)

    @property
    @pulumi.getter(name="smsNotice")
    def sms_notice(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to configure SMS notification. Valid values: `true`, `false`.
        """
        return pulumi.get(self, "sms_notice")

    @sms_notice.setter
    def sms_notice(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sms_notice", value)


@pulumi.input_type
class MonitorConfigIspCityNodeArgs:
    def __init__(__self__, *,
                 city_code: pulumi.Input[str],
                 isp_code: pulumi.Input[str]):
        """
        :param pulumi.Input[str] city_code: The code of the city node to monitor.
        :param pulumi.Input[str] isp_code: The code of the Internet provider service (ISP) node to monitor.
        """
        pulumi.set(__self__, "city_code", city_code)
        pulumi.set(__self__, "isp_code", isp_code)

    @property
    @pulumi.getter(name="cityCode")
    def city_code(self) -> pulumi.Input[str]:
        """
        The code of the city node to monitor.
        """
        return pulumi.get(self, "city_code")

    @city_code.setter
    def city_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "city_code", value)

    @property
    @pulumi.getter(name="ispCode")
    def isp_code(self) -> pulumi.Input[str]:
        """
        The code of the Internet provider service (ISP) node to monitor.
        """
        return pulumi.get(self, "isp_code")

    @isp_code.setter
    def isp_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "isp_code", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetCommandsResult',
    'AwaitableGetCommandsResult',
    'get_commands',
    'get_commands_output',
]

@pulumi.output_type
class GetCommandsResult:
    """
    A collection of values returned by getCommands.
    """
    def __init__(__self__, command_provider=None, commands=None, content_encoding=None, description=None, id=None, ids=None, name=None, name_regex=None, names=None, output_file=None, type=None):
        if command_provider and not isinstance(command_provider, str):
            raise TypeError("Expected argument 'command_provider' to be a str")
        pulumi.set(__self__, "command_provider", command_provider)
        if commands and not isinstance(commands, list):
            raise TypeError("Expected argument 'commands' to be a list")
        pulumi.set(__self__, "commands", commands)
        if content_encoding and not isinstance(content_encoding, str):
            raise TypeError("Expected argument 'content_encoding' to be a str")
        pulumi.set(__self__, "content_encoding", content_encoding)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter(name="commandProvider")
    def command_provider(self) -> Optional[str]:
        return pulumi.get(self, "command_provider")

    @property
    @pulumi.getter
    def commands(self) -> Sequence['outputs.GetCommandsCommandResult']:
        return pulumi.get(self, "commands")

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> Optional[str]:
        return pulumi.get(self, "content_encoding")

    @property
    @pulumi.getter
    def description(self) -> Optional[str]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


class AwaitableGetCommandsResult(GetCommandsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCommandsResult(
            command_provider=self.command_provider,
            commands=self.commands,
            content_encoding=self.content_encoding,
            description=self.description,
            id=self.id,
            ids=self.ids,
            name=self.name,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            type=self.type)


def get_commands(command_provider: Optional[str] = None,
                 content_encoding: Optional[str] = None,
                 description: Optional[str] = None,
                 ids: Optional[Sequence[str]] = None,
                 name: Optional[str] = None,
                 name_regex: Optional[str] = None,
                 output_file: Optional[str] = None,
                 type: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCommandsResult:
    """
    This data source provides the Ecs Commands of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.116.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ecs.get_commands(ids=["E2RY53-xxxx"],
        name_regex="tf-testAcc")
    pulumi.export("firstEcsCommandId", example.commands[0].id)
    ```


    :param str command_provider: Public order provider.
    :param str content_encoding: The Base64-encoded content of the command.
    :param str description: The description of command.
    :param Sequence[str] ids: A list of Command IDs.
    :param str name: The name of the command
    :param str name_regex: A regex string to filter results by Command name.
    :param str type: The command type.
    """
    __args__ = dict()
    __args__['commandProvider'] = command_provider
    __args__['contentEncoding'] = content_encoding
    __args__['description'] = description
    __args__['ids'] = ids
    __args__['name'] = name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['type'] = type
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('alicloud:ecs/getCommands:getCommands', __args__, opts=opts, typ=GetCommandsResult).value

    return AwaitableGetCommandsResult(
        command_provider=__ret__.command_provider,
        commands=__ret__.commands,
        content_encoding=__ret__.content_encoding,
        description=__ret__.description,
        id=__ret__.id,
        ids=__ret__.ids,
        name=__ret__.name,
        name_regex=__ret__.name_regex,
        names=__ret__.names,
        output_file=__ret__.output_file,
        type=__ret__.type)


@_utilities.lift_output_func(get_commands)
def get_commands_output(command_provider: Optional[pulumi.Input[Optional[str]]] = None,
                        content_encoding: Optional[pulumi.Input[Optional[str]]] = None,
                        description: Optional[pulumi.Input[Optional[str]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                        name: Optional[pulumi.Input[Optional[str]]] = None,
                        name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                        output_file: Optional[pulumi.Input[Optional[str]]] = None,
                        type: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCommandsResult]:
    """
    This data source provides the Ecs Commands of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.116.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.ecs.get_commands(ids=["E2RY53-xxxx"],
        name_regex="tf-testAcc")
    pulumi.export("firstEcsCommandId", example.commands[0].id)
    ```


    :param str command_provider: Public order provider.
    :param str content_encoding: The Base64-encoded content of the command.
    :param str description: The description of command.
    :param Sequence[str] ids: A list of Command IDs.
    :param str name: The name of the command
    :param str name_regex: A regex string to filter results by Command name.
    :param str type: The command type.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['SystemGroupArgs', 'SystemGroup']

@pulumi.input_type
class SystemGroupArgs:
    def __init__(__self__, *,
                 group_name: pulumi.Input[str],
                 in_protocol: pulumi.Input[str],
                 out_protocol: pulumi.Input[str],
                 play_domain: pulumi.Input[str],
                 push_domain: pulumi.Input[str],
                 callback: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a SystemGroup resource.
        :param pulumi.Input[str] group_name: The Group Name.
        :param pulumi.Input[str] in_protocol: The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        :param pulumi.Input[str] out_protocol: The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        :param pulumi.Input[str] play_domain: The domain name of plan streaming used by the group.
        :param pulumi.Input[str] push_domain: The domain name of push streaming used by the group.
        :param pulumi.Input[str] callback: The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        :param pulumi.Input[str] description: The description of Group.
        :param pulumi.Input[bool] enabled: Whether to open Group.
        """
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "in_protocol", in_protocol)
        pulumi.set(__self__, "out_protocol", out_protocol)
        pulumi.set(__self__, "play_domain", play_domain)
        pulumi.set(__self__, "push_domain", push_domain)
        if callback is not None:
            pulumi.set(__self__, "callback", callback)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Input[str]:
        """
        The Group Name.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="inProtocol")
    def in_protocol(self) -> pulumi.Input[str]:
        """
        The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        """
        return pulumi.get(self, "in_protocol")

    @in_protocol.setter
    def in_protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "in_protocol", value)

    @property
    @pulumi.getter(name="outProtocol")
    def out_protocol(self) -> pulumi.Input[str]:
        """
        The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        """
        return pulumi.get(self, "out_protocol")

    @out_protocol.setter
    def out_protocol(self, value: pulumi.Input[str]):
        pulumi.set(self, "out_protocol", value)

    @property
    @pulumi.getter(name="playDomain")
    def play_domain(self) -> pulumi.Input[str]:
        """
        The domain name of plan streaming used by the group.
        """
        return pulumi.get(self, "play_domain")

    @play_domain.setter
    def play_domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "play_domain", value)

    @property
    @pulumi.getter(name="pushDomain")
    def push_domain(self) -> pulumi.Input[str]:
        """
        The domain name of push streaming used by the group.
        """
        return pulumi.get(self, "push_domain")

    @push_domain.setter
    def push_domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "push_domain", value)

    @property
    @pulumi.getter
    def callback(self) -> Optional[pulumi.Input[str]]:
        """
        The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "callback")

    @callback.setter
    def callback(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "callback", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of Group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to open Group.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)


@pulumi.input_type
class _SystemGroupState:
    def __init__(__self__, *,
                 callback: Optional[pulumi.Input[str]] = None,
                 capture_image: Optional[pulumi.Input[int]] = None,
                 capture_interval: Optional[pulumi.Input[int]] = None,
                 capture_oss_bucket: Optional[pulumi.Input[str]] = None,
                 capture_oss_path: Optional[pulumi.Input[str]] = None,
                 capture_video: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 in_protocol: Optional[pulumi.Input[str]] = None,
                 lazy_pull: Optional[pulumi.Input[bool]] = None,
                 out_protocol: Optional[pulumi.Input[str]] = None,
                 play_domain: Optional[pulumi.Input[str]] = None,
                 push_domain: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering SystemGroup resources.
        :param pulumi.Input[str] callback: The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        :param pulumi.Input[int] capture_image: The capture image.
        :param pulumi.Input[int] capture_interval: The capture interval.
        :param pulumi.Input[str] capture_oss_bucket: The capture oss bucket.
        :param pulumi.Input[str] capture_oss_path: The capture oss path.
        :param pulumi.Input[int] capture_video: The capture video.
        :param pulumi.Input[str] description: The description of Group.
        :param pulumi.Input[bool] enabled: Whether to open Group.
        :param pulumi.Input[str] group_name: The Group Name.
        :param pulumi.Input[str] in_protocol: The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        :param pulumi.Input[bool] lazy_pull: Whether to enable on-demand streaming. Default value:`false`.
        :param pulumi.Input[str] out_protocol: The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        :param pulumi.Input[str] play_domain: The domain name of plan streaming used by the group.
        :param pulumi.Input[str] push_domain: The domain name of push streaming used by the group.
        :param pulumi.Input[bool] status: Whether to open Group. Valid values: `on`,`off`.
        """
        if callback is not None:
            pulumi.set(__self__, "callback", callback)
        if capture_image is not None:
            pulumi.set(__self__, "capture_image", capture_image)
        if capture_interval is not None:
            pulumi.set(__self__, "capture_interval", capture_interval)
        if capture_oss_bucket is not None:
            pulumi.set(__self__, "capture_oss_bucket", capture_oss_bucket)
        if capture_oss_path is not None:
            pulumi.set(__self__, "capture_oss_path", capture_oss_path)
        if capture_video is not None:
            pulumi.set(__self__, "capture_video", capture_video)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if in_protocol is not None:
            pulumi.set(__self__, "in_protocol", in_protocol)
        if lazy_pull is not None:
            pulumi.set(__self__, "lazy_pull", lazy_pull)
        if out_protocol is not None:
            pulumi.set(__self__, "out_protocol", out_protocol)
        if play_domain is not None:
            pulumi.set(__self__, "play_domain", play_domain)
        if push_domain is not None:
            pulumi.set(__self__, "push_domain", push_domain)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def callback(self) -> Optional[pulumi.Input[str]]:
        """
        The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "callback")

    @callback.setter
    def callback(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "callback", value)

    @property
    @pulumi.getter(name="captureImage")
    def capture_image(self) -> Optional[pulumi.Input[int]]:
        """
        The capture image.
        """
        return pulumi.get(self, "capture_image")

    @capture_image.setter
    def capture_image(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "capture_image", value)

    @property
    @pulumi.getter(name="captureInterval")
    def capture_interval(self) -> Optional[pulumi.Input[int]]:
        """
        The capture interval.
        """
        return pulumi.get(self, "capture_interval")

    @capture_interval.setter
    def capture_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "capture_interval", value)

    @property
    @pulumi.getter(name="captureOssBucket")
    def capture_oss_bucket(self) -> Optional[pulumi.Input[str]]:
        """
        The capture oss bucket.
        """
        return pulumi.get(self, "capture_oss_bucket")

    @capture_oss_bucket.setter
    def capture_oss_bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "capture_oss_bucket", value)

    @property
    @pulumi.getter(name="captureOssPath")
    def capture_oss_path(self) -> Optional[pulumi.Input[str]]:
        """
        The capture oss path.
        """
        return pulumi.get(self, "capture_oss_path")

    @capture_oss_path.setter
    def capture_oss_path(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "capture_oss_path", value)

    @property
    @pulumi.getter(name="captureVideo")
    def capture_video(self) -> Optional[pulumi.Input[int]]:
        """
        The capture video.
        """
        return pulumi.get(self, "capture_video")

    @capture_video.setter
    def capture_video(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "capture_video", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of Group.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to open Group.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The Group Name.
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="inProtocol")
    def in_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        """
        return pulumi.get(self, "in_protocol")

    @in_protocol.setter
    def in_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "in_protocol", value)

    @property
    @pulumi.getter(name="lazyPull")
    def lazy_pull(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable on-demand streaming. Default value:`false`.
        """
        return pulumi.get(self, "lazy_pull")

    @lazy_pull.setter
    def lazy_pull(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "lazy_pull", value)

    @property
    @pulumi.getter(name="outProtocol")
    def out_protocol(self) -> Optional[pulumi.Input[str]]:
        """
        The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        """
        return pulumi.get(self, "out_protocol")

    @out_protocol.setter
    def out_protocol(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "out_protocol", value)

    @property
    @pulumi.getter(name="playDomain")
    def play_domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name of plan streaming used by the group.
        """
        return pulumi.get(self, "play_domain")

    @play_domain.setter
    def play_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "play_domain", value)

    @property
    @pulumi.getter(name="pushDomain")
    def push_domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain name of push streaming used by the group.
        """
        return pulumi.get(self, "push_domain")

    @push_domain.setter
    def push_domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "push_domain", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to open Group. Valid values: `on`,`off`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "status", value)


class SystemGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 callback: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 in_protocol: Optional[pulumi.Input[str]] = None,
                 out_protocol: Optional[pulumi.Input[str]] = None,
                 play_domain: Optional[pulumi.Input[str]] = None,
                 push_domain: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Video Surveillance System Group resource.

        For information about Video Surveillance System Group and how to use it, see [What is Group](https://help.aliyun.com/product/108765.html).

        > **NOTE:** Available in v1.135.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.videosurveillance.SystemGroup("default",
            group_name="your_group_name",
            in_protocol="rtmp",
            out_protocol="flv",
            play_domain="your_plan_domain",
            push_domain="your_push_domain")
        ```

        ## Import

        Video Surveillance System Group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:videosurveillance/systemGroup:SystemGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] callback: The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        :param pulumi.Input[str] description: The description of Group.
        :param pulumi.Input[bool] enabled: Whether to open Group.
        :param pulumi.Input[str] group_name: The Group Name.
        :param pulumi.Input[str] in_protocol: The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        :param pulumi.Input[str] out_protocol: The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        :param pulumi.Input[str] play_domain: The domain name of plan streaming used by the group.
        :param pulumi.Input[str] push_domain: The domain name of push streaming used by the group.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SystemGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Video Surveillance System Group resource.

        For information about Video Surveillance System Group and how to use it, see [What is Group](https://help.aliyun.com/product/108765.html).

        > **NOTE:** Available in v1.135.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.videosurveillance.SystemGroup("default",
            group_name="your_group_name",
            in_protocol="rtmp",
            out_protocol="flv",
            play_domain="your_plan_domain",
            push_domain="your_push_domain")
        ```

        ## Import

        Video Surveillance System Group can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:videosurveillance/systemGroup:SystemGroup example <id>
        ```

        :param str resource_name: The name of the resource.
        :param SystemGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SystemGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 callback: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 group_name: Optional[pulumi.Input[str]] = None,
                 in_protocol: Optional[pulumi.Input[str]] = None,
                 out_protocol: Optional[pulumi.Input[str]] = None,
                 play_domain: Optional[pulumi.Input[str]] = None,
                 push_domain: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SystemGroupArgs.__new__(SystemGroupArgs)

            __props__.__dict__["callback"] = callback
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            if group_name is None and not opts.urn:
                raise TypeError("Missing required property 'group_name'")
            __props__.__dict__["group_name"] = group_name
            if in_protocol is None and not opts.urn:
                raise TypeError("Missing required property 'in_protocol'")
            __props__.__dict__["in_protocol"] = in_protocol
            if out_protocol is None and not opts.urn:
                raise TypeError("Missing required property 'out_protocol'")
            __props__.__dict__["out_protocol"] = out_protocol
            if play_domain is None and not opts.urn:
                raise TypeError("Missing required property 'play_domain'")
            __props__.__dict__["play_domain"] = play_domain
            if push_domain is None and not opts.urn:
                raise TypeError("Missing required property 'push_domain'")
            __props__.__dict__["push_domain"] = push_domain
            __props__.__dict__["capture_image"] = None
            __props__.__dict__["capture_interval"] = None
            __props__.__dict__["capture_oss_bucket"] = None
            __props__.__dict__["capture_oss_path"] = None
            __props__.__dict__["capture_video"] = None
            __props__.__dict__["lazy_pull"] = None
            __props__.__dict__["status"] = None
        super(SystemGroup, __self__).__init__(
            'alicloud:videosurveillance/systemGroup:SystemGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            callback: Optional[pulumi.Input[str]] = None,
            capture_image: Optional[pulumi.Input[int]] = None,
            capture_interval: Optional[pulumi.Input[int]] = None,
            capture_oss_bucket: Optional[pulumi.Input[str]] = None,
            capture_oss_path: Optional[pulumi.Input[str]] = None,
            capture_video: Optional[pulumi.Input[int]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            group_name: Optional[pulumi.Input[str]] = None,
            in_protocol: Optional[pulumi.Input[str]] = None,
            lazy_pull: Optional[pulumi.Input[bool]] = None,
            out_protocol: Optional[pulumi.Input[str]] = None,
            play_domain: Optional[pulumi.Input[str]] = None,
            push_domain: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[bool]] = None) -> 'SystemGroup':
        """
        Get an existing SystemGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] callback: The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        :param pulumi.Input[int] capture_image: The capture image.
        :param pulumi.Input[int] capture_interval: The capture interval.
        :param pulumi.Input[str] capture_oss_bucket: The capture oss bucket.
        :param pulumi.Input[str] capture_oss_path: The capture oss path.
        :param pulumi.Input[int] capture_video: The capture video.
        :param pulumi.Input[str] description: The description of Group.
        :param pulumi.Input[bool] enabled: Whether to open Group.
        :param pulumi.Input[str] group_name: The Group Name.
        :param pulumi.Input[str] in_protocol: The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        :param pulumi.Input[bool] lazy_pull: Whether to enable on-demand streaming. Default value:`false`.
        :param pulumi.Input[str] out_protocol: The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        :param pulumi.Input[str] play_domain: The domain name of plan streaming used by the group.
        :param pulumi.Input[str] push_domain: The domain name of push streaming used by the group.
        :param pulumi.Input[bool] status: Whether to open Group. Valid values: `on`,`off`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SystemGroupState.__new__(_SystemGroupState)

        __props__.__dict__["callback"] = callback
        __props__.__dict__["capture_image"] = capture_image
        __props__.__dict__["capture_interval"] = capture_interval
        __props__.__dict__["capture_oss_bucket"] = capture_oss_bucket
        __props__.__dict__["capture_oss_path"] = capture_oss_path
        __props__.__dict__["capture_video"] = capture_video
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["in_protocol"] = in_protocol
        __props__.__dict__["lazy_pull"] = lazy_pull
        __props__.__dict__["out_protocol"] = out_protocol
        __props__.__dict__["play_domain"] = play_domain
        __props__.__dict__["push_domain"] = push_domain
        __props__.__dict__["status"] = status
        return SystemGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def callback(self) -> pulumi.Output[Optional[str]]:
        """
        The space within the device status update of the callback, need to start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "callback")

    @property
    @pulumi.getter(name="captureImage")
    def capture_image(self) -> pulumi.Output[int]:
        """
        The capture image.
        """
        return pulumi.get(self, "capture_image")

    @property
    @pulumi.getter(name="captureInterval")
    def capture_interval(self) -> pulumi.Output[int]:
        """
        The capture interval.
        """
        return pulumi.get(self, "capture_interval")

    @property
    @pulumi.getter(name="captureOssBucket")
    def capture_oss_bucket(self) -> pulumi.Output[str]:
        """
        The capture oss bucket.
        """
        return pulumi.get(self, "capture_oss_bucket")

    @property
    @pulumi.getter(name="captureOssPath")
    def capture_oss_path(self) -> pulumi.Output[str]:
        """
        The capture oss path.
        """
        return pulumi.get(self, "capture_oss_path")

    @property
    @pulumi.getter(name="captureVideo")
    def capture_video(self) -> pulumi.Output[int]:
        """
        The capture video.
        """
        return pulumi.get(self, "capture_video")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of Group.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[bool]:
        """
        Whether to open Group.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[str]:
        """
        The Group Name.
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="inProtocol")
    def in_protocol(self) -> pulumi.Output[str]:
        """
        The use of the access protocol support gb28181, Real Time Messaging Protocol (rtmp). Valid values: `gb28181`, `rtmp`.
        """
        return pulumi.get(self, "in_protocol")

    @property
    @pulumi.getter(name="lazyPull")
    def lazy_pull(self) -> pulumi.Output[bool]:
        """
        Whether to enable on-demand streaming. Default value:`false`.
        """
        return pulumi.get(self, "lazy_pull")

    @property
    @pulumi.getter(name="outProtocol")
    def out_protocol(self) -> pulumi.Output[str]:
        """
        The playback protocol used by the space, multiple values are separated by commas (,). Valid values: `flv`,`hls`, `rtmp`.
        """
        return pulumi.get(self, "out_protocol")

    @property
    @pulumi.getter(name="playDomain")
    def play_domain(self) -> pulumi.Output[str]:
        """
        The domain name of plan streaming used by the group.
        """
        return pulumi.get(self, "play_domain")

    @property
    @pulumi.getter(name="pushDomain")
    def push_domain(self) -> pulumi.Output[str]:
        """
        The domain name of push streaming used by the group.
        """
        return pulumi.get(self, "push_domain")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[bool]:
        """
        Whether to open Group. Valid values: `on`,`off`.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['VirtualBorderRouterArgs', 'VirtualBorderRouter']

@pulumi.input_type
class VirtualBorderRouterArgs:
    def __init__(__self__, *,
                 local_gateway_ip: pulumi.Input[str],
                 peer_gateway_ip: pulumi.Input[str],
                 peering_subnet_mask: pulumi.Input[str],
                 physical_connection_id: pulumi.Input[str],
                 vlan_id: pulumi.Input[int],
                 associated_physical_connections: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 detect_multiplier: Optional[pulumi.Input[int]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 local_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 min_rx_interval: Optional[pulumi.Input[int]] = None,
                 min_tx_interval: Optional[pulumi.Input[int]] = None,
                 peer_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peering_ipv6_subnet_mask: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vbr_owner_id: Optional[pulumi.Input[str]] = None,
                 virtual_border_router_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VirtualBorderRouter resource.
        :param pulumi.Input[str] local_gateway_ip: Alibaba Cloud-Connected IPv4 address.
        :param pulumi.Input[str] peer_gateway_ip: The Client-Side Interconnection IPv4 Address.
        :param pulumi.Input[str] peering_subnet_mask: Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        :param pulumi.Input[str] physical_connection_id: The ID of the Physical Connection to Which the ID.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the VBR. Value range: 0~2999.
        :param pulumi.Input[str] associated_physical_connections: The associated physical connections.
        :param pulumi.Input[int] bandwidth: The bandwidth.
        :param pulumi.Input[str] circuit_code: Operators for physical connection circuit provided coding.
        :param pulumi.Input[str] description: The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        :param pulumi.Input[int] detect_multiplier: Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        :param pulumi.Input[bool] enable_ipv6: Whether to Enable IPv6. Valid values: `false`, `true`.
        :param pulumi.Input[str] local_ipv6_gateway_ip: Alibaba Cloud-Connected IPv6 Address.
        :param pulumi.Input[int] min_rx_interval: Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        :param pulumi.Input[int] min_tx_interval: Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        :param pulumi.Input[str] peer_ipv6_gateway_ip: The Client-Side Interconnection IPv6 Address.
        :param pulumi.Input[str] peering_ipv6_subnet_mask: Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        :param pulumi.Input[str] status: The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        :param pulumi.Input[str] vbr_owner_id: The vbr owner id.
        :param pulumi.Input[str] virtual_border_router_name: The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        """
        pulumi.set(__self__, "local_gateway_ip", local_gateway_ip)
        pulumi.set(__self__, "peer_gateway_ip", peer_gateway_ip)
        pulumi.set(__self__, "peering_subnet_mask", peering_subnet_mask)
        pulumi.set(__self__, "physical_connection_id", physical_connection_id)
        pulumi.set(__self__, "vlan_id", vlan_id)
        if associated_physical_connections is not None:
            pulumi.set(__self__, "associated_physical_connections", associated_physical_connections)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if circuit_code is not None:
            pulumi.set(__self__, "circuit_code", circuit_code)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detect_multiplier is not None:
            pulumi.set(__self__, "detect_multiplier", detect_multiplier)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if local_ipv6_gateway_ip is not None:
            pulumi.set(__self__, "local_ipv6_gateway_ip", local_ipv6_gateway_ip)
        if min_rx_interval is not None:
            pulumi.set(__self__, "min_rx_interval", min_rx_interval)
        if min_tx_interval is not None:
            pulumi.set(__self__, "min_tx_interval", min_tx_interval)
        if peer_ipv6_gateway_ip is not None:
            pulumi.set(__self__, "peer_ipv6_gateway_ip", peer_ipv6_gateway_ip)
        if peering_ipv6_subnet_mask is not None:
            pulumi.set(__self__, "peering_ipv6_subnet_mask", peering_ipv6_subnet_mask)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vbr_owner_id is not None:
            pulumi.set(__self__, "vbr_owner_id", vbr_owner_id)
        if virtual_border_router_name is not None:
            pulumi.set(__self__, "virtual_border_router_name", virtual_border_router_name)

    @property
    @pulumi.getter(name="localGatewayIp")
    def local_gateway_ip(self) -> pulumi.Input[str]:
        """
        Alibaba Cloud-Connected IPv4 address.
        """
        return pulumi.get(self, "local_gateway_ip")

    @local_gateway_ip.setter
    def local_gateway_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "local_gateway_ip", value)

    @property
    @pulumi.getter(name="peerGatewayIp")
    def peer_gateway_ip(self) -> pulumi.Input[str]:
        """
        The Client-Side Interconnection IPv4 Address.
        """
        return pulumi.get(self, "peer_gateway_ip")

    @peer_gateway_ip.setter
    def peer_gateway_ip(self, value: pulumi.Input[str]):
        pulumi.set(self, "peer_gateway_ip", value)

    @property
    @pulumi.getter(name="peeringSubnetMask")
    def peering_subnet_mask(self) -> pulumi.Input[str]:
        """
        Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        """
        return pulumi.get(self, "peering_subnet_mask")

    @peering_subnet_mask.setter
    def peering_subnet_mask(self, value: pulumi.Input[str]):
        pulumi.set(self, "peering_subnet_mask", value)

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> pulumi.Input[str]:
        """
        The ID of the Physical Connection to Which the ID.
        """
        return pulumi.get(self, "physical_connection_id")

    @physical_connection_id.setter
    def physical_connection_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "physical_connection_id", value)

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> pulumi.Input[int]:
        """
        The VLAN ID of the VBR. Value range: 0~2999.
        """
        return pulumi.get(self, "vlan_id")

    @vlan_id.setter
    def vlan_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "vlan_id", value)

    @property
    @pulumi.getter(name="associatedPhysicalConnections")
    def associated_physical_connections(self) -> Optional[pulumi.Input[str]]:
        """
        The associated physical connections.
        """
        return pulumi.get(self, "associated_physical_connections")

    @associated_physical_connections.setter
    def associated_physical_connections(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "associated_physical_connections", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The bandwidth.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> Optional[pulumi.Input[str]]:
        """
        Operators for physical connection circuit provided coding.
        """
        return pulumi.get(self, "circuit_code")

    @circuit_code.setter
    def circuit_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "circuit_code", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="detectMultiplier")
    def detect_multiplier(self) -> Optional[pulumi.Input[int]]:
        """
        Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        """
        return pulumi.get(self, "detect_multiplier")

    @detect_multiplier.setter
    def detect_multiplier(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "detect_multiplier", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to Enable IPv6. Valid values: `false`, `true`.
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="localIpv6GatewayIp")
    def local_ipv6_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv6 Address.
        """
        return pulumi.get(self, "local_ipv6_gateway_ip")

    @local_ipv6_gateway_ip.setter
    def local_ipv6_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_ipv6_gateway_ip", value)

    @property
    @pulumi.getter(name="minRxInterval")
    def min_rx_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_rx_interval")

    @min_rx_interval.setter
    def min_rx_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_rx_interval", value)

    @property
    @pulumi.getter(name="minTxInterval")
    def min_tx_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_tx_interval")

    @min_tx_interval.setter
    def min_tx_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_tx_interval", value)

    @property
    @pulumi.getter(name="peerIpv6GatewayIp")
    def peer_ipv6_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The Client-Side Interconnection IPv6 Address.
        """
        return pulumi.get(self, "peer_ipv6_gateway_ip")

    @peer_ipv6_gateway_ip.setter
    def peer_ipv6_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_ipv6_gateway_ip", value)

    @property
    @pulumi.getter(name="peeringIpv6SubnetMask")
    def peering_ipv6_subnet_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        """
        return pulumi.get(self, "peering_ipv6_subnet_mask")

    @peering_ipv6_subnet_mask.setter
    def peering_ipv6_subnet_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peering_ipv6_subnet_mask", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vbrOwnerId")
    def vbr_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vbr owner id.
        """
        return pulumi.get(self, "vbr_owner_id")

    @vbr_owner_id.setter
    def vbr_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbr_owner_id", value)

    @property
    @pulumi.getter(name="virtualBorderRouterName")
    def virtual_border_router_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "virtual_border_router_name")

    @virtual_border_router_name.setter
    def virtual_border_router_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_border_router_name", value)


@pulumi.input_type
class _VirtualBorderRouterState:
    def __init__(__self__, *,
                 associated_physical_connections: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 detect_multiplier: Optional[pulumi.Input[int]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 local_gateway_ip: Optional[pulumi.Input[str]] = None,
                 local_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 min_rx_interval: Optional[pulumi.Input[int]] = None,
                 min_tx_interval: Optional[pulumi.Input[int]] = None,
                 peer_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peer_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peering_ipv6_subnet_mask: Optional[pulumi.Input[str]] = None,
                 peering_subnet_mask: Optional[pulumi.Input[str]] = None,
                 physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vbr_owner_id: Optional[pulumi.Input[str]] = None,
                 virtual_border_router_name: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering VirtualBorderRouter resources.
        :param pulumi.Input[str] associated_physical_connections: The associated physical connections.
        :param pulumi.Input[int] bandwidth: The bandwidth.
        :param pulumi.Input[str] circuit_code: Operators for physical connection circuit provided coding.
        :param pulumi.Input[str] description: The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        :param pulumi.Input[int] detect_multiplier: Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        :param pulumi.Input[bool] enable_ipv6: Whether to Enable IPv6. Valid values: `false`, `true`.
        :param pulumi.Input[str] local_gateway_ip: Alibaba Cloud-Connected IPv4 address.
        :param pulumi.Input[str] local_ipv6_gateway_ip: Alibaba Cloud-Connected IPv6 Address.
        :param pulumi.Input[int] min_rx_interval: Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        :param pulumi.Input[int] min_tx_interval: Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        :param pulumi.Input[str] peer_gateway_ip: The Client-Side Interconnection IPv4 Address.
        :param pulumi.Input[str] peer_ipv6_gateway_ip: The Client-Side Interconnection IPv6 Address.
        :param pulumi.Input[str] peering_ipv6_subnet_mask: Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        :param pulumi.Input[str] peering_subnet_mask: Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        :param pulumi.Input[str] physical_connection_id: The ID of the Physical Connection to Which the ID.
        :param pulumi.Input[str] status: The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        :param pulumi.Input[str] vbr_owner_id: The vbr owner id.
        :param pulumi.Input[str] virtual_border_router_name: The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the VBR. Value range: 0~2999.
        """
        if associated_physical_connections is not None:
            pulumi.set(__self__, "associated_physical_connections", associated_physical_connections)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if circuit_code is not None:
            pulumi.set(__self__, "circuit_code", circuit_code)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detect_multiplier is not None:
            pulumi.set(__self__, "detect_multiplier", detect_multiplier)
        if enable_ipv6 is not None:
            pulumi.set(__self__, "enable_ipv6", enable_ipv6)
        if local_gateway_ip is not None:
            pulumi.set(__self__, "local_gateway_ip", local_gateway_ip)
        if local_ipv6_gateway_ip is not None:
            pulumi.set(__self__, "local_ipv6_gateway_ip", local_ipv6_gateway_ip)
        if min_rx_interval is not None:
            pulumi.set(__self__, "min_rx_interval", min_rx_interval)
        if min_tx_interval is not None:
            pulumi.set(__self__, "min_tx_interval", min_tx_interval)
        if peer_gateway_ip is not None:
            pulumi.set(__self__, "peer_gateway_ip", peer_gateway_ip)
        if peer_ipv6_gateway_ip is not None:
            pulumi.set(__self__, "peer_ipv6_gateway_ip", peer_ipv6_gateway_ip)
        if peering_ipv6_subnet_mask is not None:
            pulumi.set(__self__, "peering_ipv6_subnet_mask", peering_ipv6_subnet_mask)
        if peering_subnet_mask is not None:
            pulumi.set(__self__, "peering_subnet_mask", peering_subnet_mask)
        if physical_connection_id is not None:
            pulumi.set(__self__, "physical_connection_id", physical_connection_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vbr_owner_id is not None:
            pulumi.set(__self__, "vbr_owner_id", vbr_owner_id)
        if virtual_border_router_name is not None:
            pulumi.set(__self__, "virtual_border_router_name", virtual_border_router_name)
        if vlan_id is not None:
            pulumi.set(__self__, "vlan_id", vlan_id)

    @property
    @pulumi.getter(name="associatedPhysicalConnections")
    def associated_physical_connections(self) -> Optional[pulumi.Input[str]]:
        """
        The associated physical connections.
        """
        return pulumi.get(self, "associated_physical_connections")

    @associated_physical_connections.setter
    def associated_physical_connections(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "associated_physical_connections", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The bandwidth.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> Optional[pulumi.Input[str]]:
        """
        Operators for physical connection circuit provided coding.
        """
        return pulumi.get(self, "circuit_code")

    @circuit_code.setter
    def circuit_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "circuit_code", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="detectMultiplier")
    def detect_multiplier(self) -> Optional[pulumi.Input[int]]:
        """
        Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        """
        return pulumi.get(self, "detect_multiplier")

    @detect_multiplier.setter
    def detect_multiplier(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "detect_multiplier", value)

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to Enable IPv6. Valid values: `false`, `true`.
        """
        return pulumi.get(self, "enable_ipv6")

    @enable_ipv6.setter
    def enable_ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_ipv6", value)

    @property
    @pulumi.getter(name="localGatewayIp")
    def local_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv4 address.
        """
        return pulumi.get(self, "local_gateway_ip")

    @local_gateway_ip.setter
    def local_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_gateway_ip", value)

    @property
    @pulumi.getter(name="localIpv6GatewayIp")
    def local_ipv6_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv6 Address.
        """
        return pulumi.get(self, "local_ipv6_gateway_ip")

    @local_ipv6_gateway_ip.setter
    def local_ipv6_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "local_ipv6_gateway_ip", value)

    @property
    @pulumi.getter(name="minRxInterval")
    def min_rx_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_rx_interval")

    @min_rx_interval.setter
    def min_rx_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_rx_interval", value)

    @property
    @pulumi.getter(name="minTxInterval")
    def min_tx_interval(self) -> Optional[pulumi.Input[int]]:
        """
        Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_tx_interval")

    @min_tx_interval.setter
    def min_tx_interval(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "min_tx_interval", value)

    @property
    @pulumi.getter(name="peerGatewayIp")
    def peer_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The Client-Side Interconnection IPv4 Address.
        """
        return pulumi.get(self, "peer_gateway_ip")

    @peer_gateway_ip.setter
    def peer_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_gateway_ip", value)

    @property
    @pulumi.getter(name="peerIpv6GatewayIp")
    def peer_ipv6_gateway_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The Client-Side Interconnection IPv6 Address.
        """
        return pulumi.get(self, "peer_ipv6_gateway_ip")

    @peer_ipv6_gateway_ip.setter
    def peer_ipv6_gateway_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_ipv6_gateway_ip", value)

    @property
    @pulumi.getter(name="peeringIpv6SubnetMask")
    def peering_ipv6_subnet_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        """
        return pulumi.get(self, "peering_ipv6_subnet_mask")

    @peering_ipv6_subnet_mask.setter
    def peering_ipv6_subnet_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peering_ipv6_subnet_mask", value)

    @property
    @pulumi.getter(name="peeringSubnetMask")
    def peering_subnet_mask(self) -> Optional[pulumi.Input[str]]:
        """
        Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        """
        return pulumi.get(self, "peering_subnet_mask")

    @peering_subnet_mask.setter
    def peering_subnet_mask(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peering_subnet_mask", value)

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Physical Connection to Which the ID.
        """
        return pulumi.get(self, "physical_connection_id")

    @physical_connection_id.setter
    def physical_connection_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "physical_connection_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vbrOwnerId")
    def vbr_owner_id(self) -> Optional[pulumi.Input[str]]:
        """
        The vbr owner id.
        """
        return pulumi.get(self, "vbr_owner_id")

    @vbr_owner_id.setter
    def vbr_owner_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vbr_owner_id", value)

    @property
    @pulumi.getter(name="virtualBorderRouterName")
    def virtual_border_router_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "virtual_border_router_name")

    @virtual_border_router_name.setter
    def virtual_border_router_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_border_router_name", value)

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> Optional[pulumi.Input[int]]:
        """
        The VLAN ID of the VBR. Value range: 0~2999.
        """
        return pulumi.get(self, "vlan_id")

    @vlan_id.setter
    def vlan_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "vlan_id", value)


class VirtualBorderRouter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_physical_connections: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 detect_multiplier: Optional[pulumi.Input[int]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 local_gateway_ip: Optional[pulumi.Input[str]] = None,
                 local_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 min_rx_interval: Optional[pulumi.Input[int]] = None,
                 min_tx_interval: Optional[pulumi.Input[int]] = None,
                 peer_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peer_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peering_ipv6_subnet_mask: Optional[pulumi.Input[str]] = None,
                 peering_subnet_mask: Optional[pulumi.Input[str]] = None,
                 physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vbr_owner_id: Optional[pulumi.Input[str]] = None,
                 virtual_border_router_name: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Express Connect Virtual Border Router resource.

        For information about Express Connect Virtual Border Router and how to use it, see [What is Virtual Border Router](https://www.alibabacloud.com/help/en/doc-detail/44854.htm).

        > **NOTE:** Available in v1.134.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        name_regex = alicloud.expressconnect.get_physical_connections(name_regex="^my-PhysicalConnection")
        example = alicloud.expressconnect.VirtualBorderRouter("example",
            local_gateway_ip="10.0.0.1",
            peer_gateway_ip="10.0.0.2",
            peering_subnet_mask="255.255.255.252",
            physical_connection_id=name_regex.connections[0].id,
            virtual_border_router_name="example_value",
            vlan_id=1,
            min_rx_interval=1000,
            min_tx_interval=1000,
            detect_multiplier=10)
        ```

        ## Import

        Express Connect Virtual Border Router can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:expressconnect/virtualBorderRouter:VirtualBorderRouter example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] associated_physical_connections: The associated physical connections.
        :param pulumi.Input[int] bandwidth: The bandwidth.
        :param pulumi.Input[str] circuit_code: Operators for physical connection circuit provided coding.
        :param pulumi.Input[str] description: The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        :param pulumi.Input[int] detect_multiplier: Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        :param pulumi.Input[bool] enable_ipv6: Whether to Enable IPv6. Valid values: `false`, `true`.
        :param pulumi.Input[str] local_gateway_ip: Alibaba Cloud-Connected IPv4 address.
        :param pulumi.Input[str] local_ipv6_gateway_ip: Alibaba Cloud-Connected IPv6 Address.
        :param pulumi.Input[int] min_rx_interval: Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        :param pulumi.Input[int] min_tx_interval: Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        :param pulumi.Input[str] peer_gateway_ip: The Client-Side Interconnection IPv4 Address.
        :param pulumi.Input[str] peer_ipv6_gateway_ip: The Client-Side Interconnection IPv6 Address.
        :param pulumi.Input[str] peering_ipv6_subnet_mask: Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        :param pulumi.Input[str] peering_subnet_mask: Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        :param pulumi.Input[str] physical_connection_id: The ID of the Physical Connection to Which the ID.
        :param pulumi.Input[str] status: The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        :param pulumi.Input[str] vbr_owner_id: The vbr owner id.
        :param pulumi.Input[str] virtual_border_router_name: The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the VBR. Value range: 0~2999.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VirtualBorderRouterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Express Connect Virtual Border Router resource.

        For information about Express Connect Virtual Border Router and how to use it, see [What is Virtual Border Router](https://www.alibabacloud.com/help/en/doc-detail/44854.htm).

        > **NOTE:** Available in v1.134.0+.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        name_regex = alicloud.expressconnect.get_physical_connections(name_regex="^my-PhysicalConnection")
        example = alicloud.expressconnect.VirtualBorderRouter("example",
            local_gateway_ip="10.0.0.1",
            peer_gateway_ip="10.0.0.2",
            peering_subnet_mask="255.255.255.252",
            physical_connection_id=name_regex.connections[0].id,
            virtual_border_router_name="example_value",
            vlan_id=1,
            min_rx_interval=1000,
            min_tx_interval=1000,
            detect_multiplier=10)
        ```

        ## Import

        Express Connect Virtual Border Router can be imported using the id, e.g.

        ```sh
         $ pulumi import alicloud:expressconnect/virtualBorderRouter:VirtualBorderRouter example <id>
        ```

        :param str resource_name: The name of the resource.
        :param VirtualBorderRouterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VirtualBorderRouterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 associated_physical_connections: Optional[pulumi.Input[str]] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 circuit_code: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 detect_multiplier: Optional[pulumi.Input[int]] = None,
                 enable_ipv6: Optional[pulumi.Input[bool]] = None,
                 local_gateway_ip: Optional[pulumi.Input[str]] = None,
                 local_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 min_rx_interval: Optional[pulumi.Input[int]] = None,
                 min_tx_interval: Optional[pulumi.Input[int]] = None,
                 peer_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peer_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
                 peering_ipv6_subnet_mask: Optional[pulumi.Input[str]] = None,
                 peering_subnet_mask: Optional[pulumi.Input[str]] = None,
                 physical_connection_id: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vbr_owner_id: Optional[pulumi.Input[str]] = None,
                 virtual_border_router_name: Optional[pulumi.Input[str]] = None,
                 vlan_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VirtualBorderRouterArgs.__new__(VirtualBorderRouterArgs)

            __props__.__dict__["associated_physical_connections"] = associated_physical_connections
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["circuit_code"] = circuit_code
            __props__.__dict__["description"] = description
            __props__.__dict__["detect_multiplier"] = detect_multiplier
            __props__.__dict__["enable_ipv6"] = enable_ipv6
            if local_gateway_ip is None and not opts.urn:
                raise TypeError("Missing required property 'local_gateway_ip'")
            __props__.__dict__["local_gateway_ip"] = local_gateway_ip
            __props__.__dict__["local_ipv6_gateway_ip"] = local_ipv6_gateway_ip
            __props__.__dict__["min_rx_interval"] = min_rx_interval
            __props__.__dict__["min_tx_interval"] = min_tx_interval
            if peer_gateway_ip is None and not opts.urn:
                raise TypeError("Missing required property 'peer_gateway_ip'")
            __props__.__dict__["peer_gateway_ip"] = peer_gateway_ip
            __props__.__dict__["peer_ipv6_gateway_ip"] = peer_ipv6_gateway_ip
            __props__.__dict__["peering_ipv6_subnet_mask"] = peering_ipv6_subnet_mask
            if peering_subnet_mask is None and not opts.urn:
                raise TypeError("Missing required property 'peering_subnet_mask'")
            __props__.__dict__["peering_subnet_mask"] = peering_subnet_mask
            if physical_connection_id is None and not opts.urn:
                raise TypeError("Missing required property 'physical_connection_id'")
            __props__.__dict__["physical_connection_id"] = physical_connection_id
            __props__.__dict__["status"] = status
            __props__.__dict__["vbr_owner_id"] = vbr_owner_id
            __props__.__dict__["virtual_border_router_name"] = virtual_border_router_name
            if vlan_id is None and not opts.urn:
                raise TypeError("Missing required property 'vlan_id'")
            __props__.__dict__["vlan_id"] = vlan_id
        super(VirtualBorderRouter, __self__).__init__(
            'alicloud:expressconnect/virtualBorderRouter:VirtualBorderRouter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            associated_physical_connections: Optional[pulumi.Input[str]] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            circuit_code: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            detect_multiplier: Optional[pulumi.Input[int]] = None,
            enable_ipv6: Optional[pulumi.Input[bool]] = None,
            local_gateway_ip: Optional[pulumi.Input[str]] = None,
            local_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
            min_rx_interval: Optional[pulumi.Input[int]] = None,
            min_tx_interval: Optional[pulumi.Input[int]] = None,
            peer_gateway_ip: Optional[pulumi.Input[str]] = None,
            peer_ipv6_gateway_ip: Optional[pulumi.Input[str]] = None,
            peering_ipv6_subnet_mask: Optional[pulumi.Input[str]] = None,
            peering_subnet_mask: Optional[pulumi.Input[str]] = None,
            physical_connection_id: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vbr_owner_id: Optional[pulumi.Input[str]] = None,
            virtual_border_router_name: Optional[pulumi.Input[str]] = None,
            vlan_id: Optional[pulumi.Input[int]] = None) -> 'VirtualBorderRouter':
        """
        Get an existing VirtualBorderRouter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] associated_physical_connections: The associated physical connections.
        :param pulumi.Input[int] bandwidth: The bandwidth.
        :param pulumi.Input[str] circuit_code: Operators for physical connection circuit provided coding.
        :param pulumi.Input[str] description: The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        :param pulumi.Input[int] detect_multiplier: Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        :param pulumi.Input[bool] enable_ipv6: Whether to Enable IPv6. Valid values: `false`, `true`.
        :param pulumi.Input[str] local_gateway_ip: Alibaba Cloud-Connected IPv4 address.
        :param pulumi.Input[str] local_ipv6_gateway_ip: Alibaba Cloud-Connected IPv6 Address.
        :param pulumi.Input[int] min_rx_interval: Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        :param pulumi.Input[int] min_tx_interval: Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        :param pulumi.Input[str] peer_gateway_ip: The Client-Side Interconnection IPv4 Address.
        :param pulumi.Input[str] peer_ipv6_gateway_ip: The Client-Side Interconnection IPv6 Address.
        :param pulumi.Input[str] peering_ipv6_subnet_mask: Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        :param pulumi.Input[str] peering_subnet_mask: Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        :param pulumi.Input[str] physical_connection_id: The ID of the Physical Connection to Which the ID.
        :param pulumi.Input[str] status: The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        :param pulumi.Input[str] vbr_owner_id: The vbr owner id.
        :param pulumi.Input[str] virtual_border_router_name: The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        :param pulumi.Input[int] vlan_id: The VLAN ID of the VBR. Value range: 0~2999.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VirtualBorderRouterState.__new__(_VirtualBorderRouterState)

        __props__.__dict__["associated_physical_connections"] = associated_physical_connections
        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["circuit_code"] = circuit_code
        __props__.__dict__["description"] = description
        __props__.__dict__["detect_multiplier"] = detect_multiplier
        __props__.__dict__["enable_ipv6"] = enable_ipv6
        __props__.__dict__["local_gateway_ip"] = local_gateway_ip
        __props__.__dict__["local_ipv6_gateway_ip"] = local_ipv6_gateway_ip
        __props__.__dict__["min_rx_interval"] = min_rx_interval
        __props__.__dict__["min_tx_interval"] = min_tx_interval
        __props__.__dict__["peer_gateway_ip"] = peer_gateway_ip
        __props__.__dict__["peer_ipv6_gateway_ip"] = peer_ipv6_gateway_ip
        __props__.__dict__["peering_ipv6_subnet_mask"] = peering_ipv6_subnet_mask
        __props__.__dict__["peering_subnet_mask"] = peering_subnet_mask
        __props__.__dict__["physical_connection_id"] = physical_connection_id
        __props__.__dict__["status"] = status
        __props__.__dict__["vbr_owner_id"] = vbr_owner_id
        __props__.__dict__["virtual_border_router_name"] = virtual_border_router_name
        __props__.__dict__["vlan_id"] = vlan_id
        return VirtualBorderRouter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="associatedPhysicalConnections")
    def associated_physical_connections(self) -> pulumi.Output[Optional[str]]:
        """
        The associated physical connections.
        """
        return pulumi.get(self, "associated_physical_connections")

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[Optional[int]]:
        """
        The bandwidth.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="circuitCode")
    def circuit_code(self) -> pulumi.Output[Optional[str]]:
        """
        Operators for physical connection circuit provided coding.
        """
        return pulumi.get(self, "circuit_code")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of VBR. Length is from 2 to 256 characters, must start with a letter or the Chinese at the beginning, but not at the http:// Or https:// at the beginning.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="detectMultiplier")
    def detect_multiplier(self) -> pulumi.Output[int]:
        """
        Detection time multiplier that recipient allows the sender to send a message of the maximum allowable connections for the number of packets, used to detect whether the link normal. Value: 3~10.
        """
        return pulumi.get(self, "detect_multiplier")

    @property
    @pulumi.getter(name="enableIpv6")
    def enable_ipv6(self) -> pulumi.Output[bool]:
        """
        Whether to Enable IPv6. Valid values: `false`, `true`.
        """
        return pulumi.get(self, "enable_ipv6")

    @property
    @pulumi.getter(name="localGatewayIp")
    def local_gateway_ip(self) -> pulumi.Output[str]:
        """
        Alibaba Cloud-Connected IPv4 address.
        """
        return pulumi.get(self, "local_gateway_ip")

    @property
    @pulumi.getter(name="localIpv6GatewayIp")
    def local_ipv6_gateway_ip(self) -> pulumi.Output[Optional[str]]:
        """
        Alibaba Cloud-Connected IPv6 Address.
        """
        return pulumi.get(self, "local_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="minRxInterval")
    def min_rx_interval(self) -> pulumi.Output[int]:
        """
        Configure BFD packet reception interval of values include: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_rx_interval")

    @property
    @pulumi.getter(name="minTxInterval")
    def min_tx_interval(self) -> pulumi.Output[int]:
        """
        Configure BFD packet transmission interval maximum value: 200~1000, unit: ms.
        """
        return pulumi.get(self, "min_tx_interval")

    @property
    @pulumi.getter(name="peerGatewayIp")
    def peer_gateway_ip(self) -> pulumi.Output[str]:
        """
        The Client-Side Interconnection IPv4 Address.
        """
        return pulumi.get(self, "peer_gateway_ip")

    @property
    @pulumi.getter(name="peerIpv6GatewayIp")
    def peer_ipv6_gateway_ip(self) -> pulumi.Output[Optional[str]]:
        """
        The Client-Side Interconnection IPv6 Address.
        """
        return pulumi.get(self, "peer_ipv6_gateway_ip")

    @property
    @pulumi.getter(name="peeringIpv6SubnetMask")
    def peering_ipv6_subnet_mask(self) -> pulumi.Output[Optional[str]]:
        """
        Alibaba Cloud-Connected IPv6 with Client-Side Interconnection IPv6 of Subnet Mask.
        """
        return pulumi.get(self, "peering_ipv6_subnet_mask")

    @property
    @pulumi.getter(name="peeringSubnetMask")
    def peering_subnet_mask(self) -> pulumi.Output[str]:
        """
        Alibaba Cloud-Connected IPv4 and Client-Side Interconnection IPv4 of Subnet Mask.
        """
        return pulumi.get(self, "peering_subnet_mask")

    @property
    @pulumi.getter(name="physicalConnectionId")
    def physical_connection_id(self) -> pulumi.Output[str]:
        """
        The ID of the Physical Connection to Which the ID.
        """
        return pulumi.get(self, "physical_connection_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The instance state. Valid values: `active`, `deleting`, `recovering`, `terminated`, `terminating`, `unconfirmed`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vbrOwnerId")
    def vbr_owner_id(self) -> pulumi.Output[Optional[str]]:
        """
        The vbr owner id.
        """
        return pulumi.get(self, "vbr_owner_id")

    @property
    @pulumi.getter(name="virtualBorderRouterName")
    def virtual_border_router_name(self) -> pulumi.Output[Optional[str]]:
        """
        The name of VBR. Length is from 2 to 128 characters, must start with a letter or the Chinese at the beginning can contain numbers, the underscore character (_) and dash (-). But do not start with http:// or https:// at the beginning.
        """
        return pulumi.get(self, "virtual_border_router_name")

    @property
    @pulumi.getter(name="vlanId")
    def vlan_id(self) -> pulumi.Output[int]:
        """
        The VLAN ID of the VBR. Value range: 0~2999.
        """
        return pulumi.get(self, "vlan_id")

